# Chính sách phát hành

## Versioning

- Stable tags: `vX.Y.Z`
- Pre-release tags: `vX.Y.Z-rc.N`

## Pipeline phát hành

1. Quality gate
2. Build artifacts
3. Publish PyPI
4. Tạo GitHub Release
5. Publish docs khi push vào `main`

## Changelog

Được sinh từ Conventional Commits và curated release notes.
